@@ -33,9 +33,59 @@ HTML_CTX = ElementContextManager()
 
 
 class AbstractElement:
+    """
+    A Vue component which can integrate with the rest of trame
+
+    See Vue docs |vue_doc_link| for more info
+
+    .. |vue_doc_link| raw:: html
+
+        <a href="https://vuejs.org/v2/guide/instance.html" target="_blank">here</a>
+
+    .. |mdn_doc_link| raw:: html
+
+        <a href="https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes" target="_blank">here</a>
+
+    .. |mdn_event_link| raw:: html
+
+        <a href="https://developer.mozilla.org/en-US/docs/Web/API/Element#mouse_events">here</a>
+
+    :param name: The name of the element, like 'div' for a ``<div/>`` element
+    :type name: str
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    :param __properties: Provide more attribute names that should be handle
+    :param __events: Provide more event names that should be handle
+
+    Html attributes - See |mdn_doc_link| for more info
+
+    :param id: See |mdn_doc_link| for more info
+    :param classes: Match the HTML `class` attribute. See |mdn_doc_link| for more info
+    :param style: See |mdn_doc_link| for more info
+
+    Vue attributes - See |vue_doc_link| for more info
+
+    :param ref: See |vue_doc_link| for more info
+    :param v_model: See |vue_doc_link| for more info
+    :param v_if: See |vue_doc_link| for more info
+    :param v_show: See |vue_doc_link| for more info
+    :param v_for: See |vue_doc_link| for more info
+    :param key: See |vue_doc_link| for more info
+
+    Events - See |mdn_event_link| for more info
+
+    :param click: See |mdn_event_link| for more info
+    :param mousedown: See |mdn_event_link| for more info
+    :param mouseup: See |mdn_event_link| for more info
+    :param mouseenter: See |mdn_event_link| for more info
+    :param mouseleave: See |mdn_event_link| for more info
+    :param contextmenu: See |mdn_event_link| for more info
+
+    """
+
     _next_id = 1
 
-    def __init__(self, name, __content=None, children=None, **kwargs):
+    def __init__(self, name, children=None, **kwargs):
         AbstractElement._next_id += 1
         self._id = AbstractElement._next_id
         self._elem_name = name
@@ -44,21 +94,14 @@ class AbstractElement:
         self._event_names = kwargs.get("__events", [])
 
         self._attributes = {}
-        self._txt = None
         self._py_attr = kwargs
         self._children = []
 
-        if __content:
-            if isinstance(__content, str):
-                self._txt = __content
-            elif isinstance(__content, list):
-                self._children.extend(__content)
-            else:
-                self._children.append(__content)
-
-        # Add standard Vue attribute handling
         if children:
-            self._children.extend(children)
+            if isinstance(children, list):
+                self._children.extend(children)
+            else:
+                self._children.append(children)
 
         # Add standard Vue attr/event handling
         self._attr_names += [
@@ -81,7 +124,7 @@ class AbstractElement:
             "contextmenu",
         ]
 
-        # Add ourself to context is any
+        # Add ourself to context if any
         HTML_CTX.add_child(self)
 
     def _attr_str(self):
@@ -118,8 +161,6 @@ class AbstractElement:
     def __setattr__(self, name, value):
         if name[0] == "_":
             self.__dict__[name] = value
-        elif name == "content":
-            self._txt = value
         elif name == "children":
             self._children = value
         elif name in self._allowed_keys:
@@ -135,10 +176,26 @@ class AbstractElement:
     # -------------------------------------------------------------------------
 
     def ttsSensitive(self):
+        """
+        Calling this function on an element will make it fully recreate itself
+        every time the layout update. Internally it is managed by adding a `key=`
+        attribute which use a layout timestamp.
+
+        This is especially useful for component that manage other elements outside
+        of themself like VSelect in Vuetify.
+        """
         self._attributes["__tts"] = f':key="`w{self._id}-${{tts}}`"'
         return self
 
     def attrs(self, *names):
+        """
+        Calling this function will process the provided attribute names and
+        configure its internal so the macthing HTML string could easily be
+        generated later on.
+
+        :param names: The names attribute to process
+        :type names: *str
+        """
         _app = get_app_instance()
         for _name in names:
             js_key = None
@@ -161,7 +218,7 @@ class AbstractElement:
                     and not isinstance(value, (tuple, list))
                 ):
                     print(
-                        f'Warning: A Vue directive is evaluating your expression and Trame would expect a tuple instead of a plain type. <{self._elem_name} {js_key}="{value}" ... />'
+                        f'Warning: A Vue directive is evaluating your expression and trame would expect a tuple instead of a plain type. <{self._elem_name} {js_key}="{value}" ... />'
                     )
 
                 if isinstance(value, (tuple, list)):
@@ -187,6 +244,14 @@ class AbstractElement:
         return self
 
     def events(self, *names):
+        """
+        Calling this function will process the provided event names and
+        configure its internal so the macthing HTML string could easily be
+        generated later on.
+
+        :param names: The names events to process
+        :type names: *str
+        """
         _app = get_app_instance()
         for _name in names:
             js_key = None
@@ -231,28 +296,58 @@ class AbstractElement:
         return self
 
     def clear(self):
-        self._txt = None
+        """
+        Remove all children
+        """
         self._children.clear()
 
     def hide(self):
+        """
+        Hide element while keeping it in the DOM. (display: none)
+        """
         self._attributes["__style"] = 'style="display: none"'
 
     def add_child(self, child):
+        """
+        Add a component to this component's children
+
+        :param child: The component to add as a child
+        :type child: str | AbstractElement
+        """
         self._children.append(child)
 
     def add_children(self, children):
+        """
+        Add components to this component's children.
+        The provided children is expected to be a list.
+
+        :param children: The list of components to add to the children
+        :type children: list
+        """
         self._children += children
 
-    @property
-    def content(self):
-        return self._txt
-
     @property
     def children(self):
+        """
+        Children components
+        """
         return self._children
 
+    def set_text(self, value):
+        """
+        Replace children with a single text child element
+
+        :param value: The text for the new text child element
+        :type value: str
+        """
+        self.clear()
+        self._children.append(value)
+
     @property
     def html(self):
+        """
+        Return a string representation of the HTML component
+        """
         # Build attributes
         self.attrs(*self._attr_names)
         self.events(*self._event_names)
@@ -268,10 +363,6 @@ class AbstractElement:
                     out_buffer.append(child.html)
             out_buffer.append(f"</{self._elem_name}>")
             return "\n".join(out_buffer)
-        elif self._txt:
-            return (
-                f"<{self._elem_name} {self._attr_str()}>{self._txt}</{self._elem_name}>"
-            )
         else:
             return f"<{self._elem_name} {self._attr_str()} />"
 
@@ -288,34 +379,78 @@ class AbstractElement:
 
 
 class Element(AbstractElement):
-    def __init__(self, __elem_name, __content=None, **kwargs):
-        super().__init__(__elem_name, __content, **kwargs)
+    """
+    Any html element you would like to use in trame
+
+    :param _elem_name: The name of the element, like 'div' for a ``<div/>`` element
+    :type _elem_name: str
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, _elem_name, children=None, **kwargs):
+        super().__init__(_elem_name, children, **kwargs)
 
 
 class Div(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("div", __content, **kwargs)
+    """
+    The standard html content div element
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, children=None, **kwargs):
+        super().__init__("div", children, **kwargs)
 
 
 class Span(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("span", __content, **kwargs)
+    """
+    The standard html content span element
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, children=None, **kwargs):
+        super().__init__("span", children, **kwargs)
 
 
 class Form(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("form", __content, **kwargs)
+    """
+    The standard html form element
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, children=None, **kwargs):
+        super().__init__("form", children, **kwargs)
         self._attr_names += ["action"]
 
 
 class Label(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("label", __content, **kwargs)
+    """
+    The standard html input label element
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, children=None, **kwargs):
+        super().__init__("label", children, **kwargs)
 
 
 class Input(AbstractElement):
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("input", __content, **kwargs)
+    """
+    The standard html input (form input) element
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    """
+
+    def __init__(self, children=None, **kwargs):
+        super().__init__("input", children, **kwargs)
         self._attr_names += [
             "type",
             "value",
@@ -342,10 +477,23 @@ class Input(AbstractElement):
 
 
 class Template(AbstractElement):
+    """
+    The standard html content template element. This is mostly used by |slot_doc_link|.
+
+    .. |slot_doc_link| raw:: html
+
+        <a href="https://vuejs.org/v2/guide/instance.html" target="_blank">vue's slot system</a>
+
+
+    :param children: The children nested within this element
+    :type children:  str | list[trame.html.*] | trame.html.* | None
+    :param v_slot: The slot this template corresponds to
+    """
+
     slot_names = set()
 
-    def __init__(self, __content=None, **kwargs):
-        super().__init__("template", __content, **kwargs)
+    def __init__(self, children=None, **kwargs):
+        super().__init__("template", children, **kwargs)
         self._attr_names += ["v_slot"]
         for slot_name in Template.slot_names:
             safe_name = slot_name.replace("-", "_").replace(".", "_")
@@ -365,7 +513,19 @@ class Template(AbstractElement):
                 self._attr_names.append((f"v_slot_{safe_name}", f"v-slot:{slot_name}"))
 
 
-class StateUpdate(AbstractElement):
+class StateChange(AbstractElement):
+    """
+    Component to react when a state entry change so an event can be triggered
+
+    :param name: Which part of the state to listen to
+    :type name: str
+
+    Events
+
+    :param change: Function to run if state changes
+    :type change: function
+    """
+
     def __init__(self, name, **kwargs):
         super().__init__("py-state-update", **kwargs)
         self._attributes["value"] = f':value="{name}"'
@@ -375,6 +535,18 @@ class StateUpdate(AbstractElement):
 
 
 class Triggers(AbstractElement):
+    """
+    Component to trigger JS actions from Python
+
+    :param ref: Name for Vue reference to this object
+    :type ref: str
+    :param triggers: Mapping from names of triggers to expressions or methods in JS which they will call
+    :type triggers: dict[str, str]
+
+    >>> triggers = trame.html.Triggers(ref="all_triggers", triggers={ "reset_camera": "$refs.view.resetCamera()" })
+
+    """
+
     def __init__(self, ref, triggers={}, **kwargs):
         super().__init__("py-trigger", **kwargs)
         self._ref = ref
@@ -383,8 +555,31 @@ class Triggers(AbstractElement):
             self._attributes[f"_{key}"] = f'@{key}="{value}"'
 
     def add(self, name, call):
+        """
+        Add a trigger which can call JS from Python
+
+        :param name: Reference for this JS method or expression trigger
+        :type name: str
+        :param call: JS method or expression to call when triggered
+        :type call: str
+
+        >>> triggers.add("created", "console.log('UI is created')")
+        >>> triggers.add("mounted", "console.log('UI is mounted')")
+        >>> triggers.add("beforeDestroy", "console.log('UI is going away')")
+
+        """
         self._attributes[f"_{name}"] = f'@{name}="{call}"'
 
     def call(self, name, *args):
+        """
+        Trigger JS code previously added to this object
+
+        :param name: Reference for this JS method or expression trigger
+        :type name: str
+        :param args: Parameters passed to JS method
+
+        >>> triggers.call("reset_camera")
+
+        """
         _app = get_app_instance()
         _app.update(ref=self._ref, method="emit", args=[name, *args])
